var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cleanProps from 'clean-react-props';

var SECOND = 1000;
var MINUTE = 60 * 1000;
var HOUR = 60 * 60 * 1000;

var Timecode = function (_Component) {
  _inherits(Timecode, _Component);

  function Timecode() {
    _classCallCheck(this, Timecode);

    return _possibleConstructorReturn(this, _Component.apply(this, arguments));
  }

  Timecode.prototype.pad = function pad(number) {
    var length = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 2;

    var numberLength = number.toString().length;
    if (numberLength < length) {
      var diff = length - numberLength;
      var padding = '';

      while (padding.length < diff) {
        padding += '0';
      }

      return '' + padding + number;
    }

    return number;
  };

  Timecode.prototype.formatMilliseconds = function formatMilliseconds(milliseconds) {
    return this.pad((milliseconds / 1000).toFixed(3) * 1000, 3);
  };

  Timecode.prototype.formatTimecode = function formatTimecode(_ref) {
    var hours = _ref.hours,
        minutes = _ref.minutes,
        seconds = _ref.seconds,
        milliseconds = _ref.milliseconds;
    var format = this.props.format;


    switch (format) {
      case 'HH:mm:ss.sss':
        return this.pad(hours) + ':' + this.pad(minutes) + ':' + this.pad(seconds) + '.' + this.formatMilliseconds(milliseconds);

      case 'H:mm:ss.sss':
        return hours + ':' + this.pad(minutes) + ':' + this.pad(seconds) + '.' + this.formatMilliseconds(milliseconds);

      case 'H:?mm:ss.sss':
        if (hours) {
          return hours + ':' + this.pad(minutes) + ':' + this.pad(seconds) + '.' + this.formatMilliseconds(milliseconds);
        }

        return this.pad(minutes) + ':' + this.pad(seconds) + '.' + this.formatMilliseconds(milliseconds);

      case 'H:?m:ss.sss':
        if (hours) {
          return hours + ':' + this.pad(minutes) + ':' + this.pad(seconds) + '.' + this.formatMilliseconds(milliseconds);
        }

        return minutes + ':' + this.pad(seconds) + '.' + this.formatMilliseconds(milliseconds);

      case 'HH:mm:ss':
        return this.pad(hours) + ':' + this.pad(minutes) + ':' + this.pad(seconds);

      case 'H:mm:ss':
        return hours + ':' + this.pad(minutes) + ':' + this.pad(seconds);

      case 'H:?mm:ss':
        if (hours) {
          return hours + ':' + this.pad(minutes) + ':' + this.pad(seconds);
        }

        return this.pad(minutes) + ':' + this.pad(seconds);

      case 'H:mm':
        return hours + ':' + this.pad(minutes);

      case 'H:?m:ss':
      default:
        if (hours) {
          return hours + ':' + this.pad(minutes) + ':' + this.pad(seconds);
        }

        return minutes + ':' + this.pad(seconds);
    }
  };

  Timecode.prototype.render = function render() {
    var _props = this.props,
        component = _props.component,
        prefix = _props.prefix,
        postfix = _props.postfix,
        time = _props.time;


    var milliseconds = time;

    var hours = milliseconds >= HOUR ? Math.floor(milliseconds / HOUR) : 0;

    if (hours) {
      milliseconds -= hours * HOUR;
    }

    var minutes = milliseconds >= MINUTE ? Math.floor(milliseconds / MINUTE) : 0;

    if (minutes) {
      milliseconds -= minutes * MINUTE;
    }

    var seconds = milliseconds >= SECOND ? Math.floor(milliseconds / SECOND) : 0;

    if (seconds) {
      milliseconds -= seconds * SECOND;
    }

    return React.createElement(component, _extends({}, cleanProps(this.props, ['prefix', 'postfix'])), ['' + prefix + this.formatTimecode({ hours: hours, minutes: minutes, seconds: seconds, milliseconds: milliseconds }) + postfix]);
  };

  return Timecode;
}(Component);

Timecode.propTypes = {
  component: PropTypes.oneOfType([PropTypes.func, PropTypes.string]),
  format: PropTypes.string,
  prefix: PropTypes.string,
  postfix: PropTypes.string,
  time: PropTypes.number
};

Timecode.defaultProps = {
  component: 'span',
  format: 'H:?m:ss',
  prefix: '',
  postfix: '',
  time: 0
};

export default Timecode;